@@ -5,8 +5,6 @@ package Cobol::Compiler::COBOLMainLexer;
 use parent 'Lexer';
 use feature "switch";
 
-use constant MAIN => qw(IDENTIFICATION PROGRAM-ID);
-
 sub new {
 	my ($class) = @_;
 
@@ -24,10 +22,10 @@ sub switch {
 
 	### return references to ID classes in symbol table
 	given ($s) {
-	when (Cobol::Compiler::COBOLMainLexer->IDENTIFICATION) { 
+	when (Cobol::Compiler::ProgramToken->IDENTIFICATION) {
 		return \$self->{mastersymtab}->{IDENTIFICATION}	
 	}
-	when (Cobol::Compiler::COBOLMainLexer->PROGRAM-ID) {  }
+	when (Cobol::Compiler::ProgramToken->PROGRAM-ID) { 
 		return \$self->{mastersymtab}->{PROGRAM-ID}	
 	}
 
