@@ -6,7 +6,7 @@ sub new {
 	### set up IDs (symbols) for the master compiling system
 	my $self = { IDENTIFICATION => Cobol::Compiler::ProgramID->new(""),
 			PROGRAM-ID => Cobol::Compiler::ProgramID->new(""),
-			MAINPROCEDURE => Cobol::Compiler::ProcedureID->new(""), };
+	};
 
 	$class = ref($class) || $class;
 
