@@ -1,4 +1,4 @@
-package Cobol::Compiler::ProcedureTokenInstaller;
+package Cobol::Compiler::DataTokenInstaller;
 
 ### This is a string token installer to the ProcedureID class
 
