@@ -1,5 +1,8 @@
 package Cobol::Compiler::Lexer;
 
+### use constant => qw(DATA PROCEDURE WORKING-STORAGE);
+use feature "switch";
+
 sub new {
 	my ($class) = @_;
 
@@ -10,9 +13,4 @@ sub new {
 	bless $self, $class;
 }
 
-sub switch {
-	my ($self) = @_;
-
-}
-
 1;
